@@ -1,5 +1,5 @@
 package Clipboard::Xclip;
-$Clipboard::Xclip::VERSION = '0.25';
+$Clipboard::Xclip::VERSION = '0.27';
 use strict;
 use warnings;
 
@@ -25,7 +25,8 @@ sub copy_to_selection {
     my ($selection, $input) = @_;
     my $cmd = '|xclip -i -selection '. $selection;
     my $r = open my $exe, $cmd or die "Couldn't run `$cmd`: $!\n";
-    print $exe $input;
+    binmode $exe, ':encoding(UTF-8)';
+    print {$exe} $input;
     close $exe or die "Error closing `$cmd`: $!";
 
     return;
@@ -87,7 +88,7 @@ __END__
 
 =head1 VERSION
 
-version 0.25
+version 0.27
 
 =for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
@@ -181,7 +182,7 @@ feature.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by Ryan King <rking@panoptic.com>.
+This software is copyright (c) 2021 by Ryan King <rking@panoptic.com>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
